==> apache-superset-3.0.4-source.tar.gz: apache-superset-3.0.4rc1/tests/unit_tests/queries/dao_test.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
import json


def test_column_attributes_on_query():
    from superset.daos.query import QueryDAO
    from superset.models.core import Database
    from superset.models.sql_lab import Query

    db = Database(database_name="my_database", sqlalchemy_uri="sqlite://")
    query_obj = Query(
        client_id="foo",
        database=db,
        tab_name="test_tab",
        sql_editor_id="test_editor_id",
        sql="select * from bar",
        select_sql="select * from bar",
        executed_sql="select * from bar",
        limit=100,
        select_as_cta=False,
        rows=100,
        error_message="none",
        results_key="abc",
    )

    columns = [{"name": "test", "is_dttm": False, "type": "INT"}]
    payload = {"columns": columns}

    QueryDAO.save_metadata(query_obj, payload)
    assert "column_name" in json.loads(query_obj.extra_json).get("columns")[0]

==> apache-superset-4.0.2-source.tar.gz: apache-superset-4.0.2rc2/tests/unit_tests/queries/dao_test.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
import json


def test_column_attributes_on_query():
    from superset.daos.query import QueryDAO
    from superset.models.core import Database
    from superset.models.sql_lab import Query

    database = Database(database_name="my_database", sqlalchemy_uri="sqlite://")
    query_obj = Query(
        client_id="foo",
        database=database,
        tab_name="test_tab",
        sql_editor_id="test_editor_id",
        sql="select * from bar",
        select_sql="select * from bar",
        executed_sql="select * from bar",
        limit=100,
        select_as_cta=False,
        rows=100,
        error_message="none",
        results_key="abc",
    )

    columns = [{"name": "test", "is_dttm": False, "type": "INT"}]
    payload = {"columns": columns}

    QueryDAO.save_metadata(query_obj, payload)
    assert "column_name" in json.loads(query_obj.extra_json).get("columns")[0]
